@@ -9,30 +9,39 @@
 #' given. Confidence intervals are displayed when they are part of the fitted
 #' object.
 #' 
-#' @param object
-#' 
-#' An object with class `prodlim' derived with \code{\link{prodlim}}
-#' @param times Vector of times at which to return the estimated probabilities.
-#' @param newdata A data frame with the same variable names as those that
-#' appear on the right hand side of the 'prodlim' formula.  Defaults to
-#' \code{object$X}.
-#' @param max.tables Integer. If \code{newdata} is not given the value of
-#' \code{max.tables} decides about the maximal number of tables to be shown.
-#' Defaults to 20.
-#' @param surv Logical. If FALSE report event probabilities instead of survival
-#' probabilities. Only available for \code{object$model=="survival"}.
-#' @param cause The cause for predicting the cause-specific cumulative
-#' incidence function in competing risk models.
-#' @param intervals Logical. If TRUE count events and censored in intervals
-#' between the values of \code{times}.
-#' @param percent Logical. If TRUE all estimated values are multiplied by 100
-#' and thus interpretable on a percent scale.
-#' @param showTime If \code{TRUE} evaluation times are put into a column of the
-#' output table, otherwise evaluation times are shown as rownames.
-#' @param \dots Further arguments that are passed to the print function.
+#' @param object An object with class `prodlim' derived with
+#' \code{\link{prodlim}}
+#' @param times Vector of times at which to return the estimated
+#' probabilities.
+#' @param newdata A data frame with the same variable names as those
+#' that appear on the right hand side of the 'prodlim' formula.
+#' Defaults to \code{object$X}.
+#' @param max.tables Integer. If \code{newdata} is not given the value
+#' of \code{max.tables} decides about the maximal number of tables to
+#' be shown.  Defaults to 20.
+#' @param surv Logical. If FALSE report event probabilities instead of
+#' survival probabilities. Only available for
+#' \code{object$model=="survival"}.
+#' @param cause For competing risk models. The event of interest for which predictions of the absolute risks are obtained by evaluating the cause-specific cumulative
+#' incidence functions at  \code{times}.
+#' @param intervals Logical. If TRUE count events and censored in
+#' intervals between the values of \code{times}.
+#' @param percent Logical. If TRUE all estimated values are multiplied
+#' by 100 and thus interpretable on a percent scale.
+#' @param showTime If \code{TRUE} evaluation times are put into a
+#' column of the output table, otherwise evaluation times are shown as
+#' rownames.
+#' @param asMatrix Control the output format when there are multiple
+#' life tables, either because of covariate strata or competing causes
+#' or both.  If not missing and not FALSE, reduce multiple life tables
+#' into a matrix with new columns \code{X} for covariate strata and
+#' \code{Event} for competing risks.
+#' @param ... Further arguments that are passed to the print
+#' function.
 #' @return A data.frame with the relevant information.
 #' @author Thomas A. Gerds \email{tag@@biostat.ku.dk}
 #' @seealso \code{\link{prodlim}}, \code{\link{summary.Hist}}
+#' 
 #' @keywords survival
 ##' @examples
 ##' 
@@ -63,7 +72,7 @@
 ##' sx <- summary(fit0,times=c(1,5,10,12),percent=TRUE,intervals=TRUE)
 ##' print(sx,digits=3)
 ##' 
-##' ## show cumulative incidences (1-survival)
+##' ## show absolute risks, i.e., cumulative incidences (1-survival)
 ##' summary(fit0,times=c(1,5,10,12),surv=FALSE,percent=TRUE,intervals=TRUE)
 ##' 
 ##' # Stratified Kaplan-Meier
@@ -72,10 +81,12 @@
 ##' fit1 <- prodlim(Hist(time,event)~sex,data=d)
 ##' print(summary(fit1,times=c(1,5,10),intervals=TRUE,percent=TRUE),digits=3)
 ##' 
+##' summary(fit1,times=c(1,5,10),asMatrix=TRUE,intervals=TRUE,percent=TRUE)
+##' 
 ##' fit2 <- prodlim(Hist(time,event)~Z,data=d)
 ##' print(summary(fit2,times=c(1,5,10),intervals=TRUE,percent=TRUE),digits=3)
 ##' 
-##' ## Beran estimator
+##' ## Continuous strata (Beran estimator)
 ##' # -----------------------------------------------------------------------------------------
 ##' fit3 <- prodlim(Hist(time,event)~age,data=d)
 ##' print(summary(fit3,
@@ -93,26 +104,36 @@
 ##'               intervals=TRUE,
 ##'               percent=TRUE),digits=3)
 ##' 
+##' print(summary(fit4,
+##'               times=c(1,5,10),
+##'               newdata=data.frame(age=c(20,50,70),sex=c("female","male","male")),
+##'               intervals=TRUE,
+##'               percent=TRUE),digits=3)
+##' 
 ##' ## assess results from summary
 ##' x <- summary(fit4,times=10,newdata=expand.grid(age=c(60,40,50),sex=c("male","female")))
 ##' cbind(names(x$table),do.call("rbind",lapply(x$table,round,2)))
 ##' 
+##' x <- summary(fit4,times=10,newdata=expand.grid(age=c(60,40,50),sex=c("male","female")))
+##' 
 ##' ## Competing risks: Aalen-Johansen
 ##' # -----------------------------------------------------------------------------------------
 ##' d <- SimCompRisk(30)
 ##' crfit <- prodlim(Hist(time,event)~X1,data=d)
 ##' summary(crfit,times=c(1,2,5))
 ##' summary(crfit,times=c(1,2,5),cause=1,intervals=TRUE)
+##' summary(crfit,times=c(1,2,5),cause=1,asMatrix=TRUE)
+##' summary(crfit,times=c(1,2,5),cause=1:2,asMatrix=TRUE)
 ##' 
-##' # extract the results 
+##' 
+##' # extract the actual tables from the summary 
 ##' sumfit <- summary(crfit,times=c(1,2,5),print=FALSE)
 ##' sumfit$table[[1]] # cause 1
 ##' sumfit$table[[2]] # cause 2
 ##' 
 ##' 
 ##' # '
-#' @S3method summary prodlim
-#' @method summary prodlim
+#' @export 
 summary.prodlim <- function(object,
                             times,
                             newdata,
@@ -122,15 +143,16 @@ summary.prodlim <- function(object,
                             intervals=FALSE,
                             percent=FALSE,
                             showTime=TRUE,
+                            asMatrix=FALSE,
                             ...) {
-    # }}}
-    # {{{  classify the situation
+                                        # }}}
+                                        # {{{  classify the situation
     cens.type <- object$cens.type         # uncensored, right or interval censored
     model <- object$model                 # survival, competing risks or multi-state
     ## cluster <- object$clustervar          # clustered data?
     cotype <- object$covariate.type       # no, discrete, continuous or both
-    # }}}
-    # {{{  times
+                                        # }}}
+                                        # {{{  times
     jump.times <- object$time
     if (missing(times) && (length(times <- jump.times) > 50)) 
         times <- quantile(sort(unique(jump.times)))
@@ -141,31 +163,31 @@ summary.prodlim <- function(object,
                 paste("\n","Time(s) ",paste(times[times>max(jump.times)],collapse=", "),
                       " are beyond the maximal follow-up time ",max(jump.times),"\n"))
     ntimes <- length(times)
-    # }}}
-    # {{{ interval-censored
+                                        # }}}
+                                        # {{{ interval-censored
     if (cens.type=="intervalCensored"){
         ltab <- data.frame(time=paste("(",paste(signif(object$time[1,],2),
-                               signif(object$time[2,],2),
-                               sep="-"),"]",sep=""),
+                                                signif(object$time[2,],2),
+                                                sep="-"),"]",sep=""),
                            n.risk=signif(object$n.risk,2),
                            n.event=signif(object$n.event,2),
                            ##    n.lost=object$n.lost,
                            surv=object$surv)
     }
     else{
-        # }}}
-        # {{{ with covariates
+                                        # }}}
+                                        # {{{ with covariates
         if (cotype>1){
             if (missing(newdata) || length(newdata)==0){
                 X <- object$X
                 if (NROW(X)>max.tables){
                     warning(call.=TRUE,immediate.=TRUE,paste("\nLife tables are available for",
-                                           NROW(X),
-                                           "different covariate constellations.\n",
-                                           "Shown are the table corresponding to the first row in object$X,",
-                                           "corresponding to the middle row (median of the number of rows in object$X) ",
-                                           "and corresponding to the last row in object$X ...\n",
-                                           "to see more tables use arguments `newdata' and `max.tables'\n"))
+                                                             NROW(X),
+                                                             "different covariate constellations.\n",
+                                                             "Shown are the table corresponding to the first row in object$X,",
+                                                             "corresponding to the middle row (median of the number of rows in object$X) ",
+                                                             "and corresponding to the last row in object$X ...\n",
+                                                             "to see more tables use arguments `newdata' and `max.tables'\n"))
                     X <- X[c(1,round(median(1:NROW(X))),NROW(X)),,drop=FALSE]
                 }
             } else{
@@ -196,47 +218,53 @@ summary.prodlim <- function(object,
             stats <- list(c("cuminc",0),c("se.cuminc",0))
             if (!is.null(object$conf.int))
                 stats <- c(stats,list(c("lower",0),c("upper",0)))
-        }
-        ltab <- lifeTab(object=object,
-                        times=times,
-                        newdata=X,
-                        stats=stats,
-                        intervals=intervals,
-                        percent=percent,
-                        showTime=showTime)
-        if (model=="competing.risks"){
             if (!missing(cause)){
-                if (is.numeric(cause) && !is.numeric(names(ltab)))
-                    cause <- attr(object$model.response,"states")[cause]
+                cause <- checkCauses(cause=cause,object=object)
             } else{ ## show all causes
                 cause <- attr(object$model.response,"states")
             }
-            # found <- match(cause,attr(object$model.response,"states"),nomatch=FALSE))
-            Found <- match(cause,names(ltab))
-            if (all(Found)) ltab <- ltab[Found]
-            else warning("could not find requested causes in attributes of object$mode.response")
+            ltab <- lifeTab(object=object,
+                            times=times,
+                            cause=cause,
+                            newdata=X,
+                            stats=stats,
+                            intervals=intervals,
+                            percent=percent,
+                            showTime=showTime)
+            Found <- match(cause,names(ltab),nomatch=0)
+            if (all(Found)>0) {
+                ltab <- ltab[Found]
+            }
+            else stop(paste("\nCannot find cause: ",cause,".\nFitted were causes: ",paste(names(ltab),collapse=", "),sep=""))
+        }else{
+            ltab <- lifeTab(object=object,
+                            times=times,
+                            newdata=X,
+                            stats=stats,
+                            intervals=intervals,
+                            percent=percent,
+                            showTime=showTime)
         }
     }
-    # }}}
-    # {{{ output
-    if (is.list(ltab)) {
-        tab <- lapply(ltab,function(x){
-            if (is.list(x)) {
-                lapply(x,data.frame) }
-            else{
-                data.frame(as.matrix(x))
-            }
-        })
+                                        # }}}
+                                        # {{{ output
+    if (asMatrix!=FALSE) asMatrix <- TRUE
+    if (model=="competing.risks"){
+        ## out <- list(table=ltab,cause=cause)
+        if (asMatrix)
+            if (cotype>1)
+                ltab <- List2Matrix(ltab,depth=2,names=c("Event","X"))
+            else
+                ltab <- List2Matrix(ltab,depth=1,names=c("Event"))
+        
+    }else{
+         if(cotype>1 && asMatrix)
+             ltab <- List2Matrix(ltab,depth=1,names="X")
+     }
+    out <- list(table=ltab,model=model,cotype=cotype,asMatrix=asMatrix,percent=percent)
+    if (model=="competing.risks"){
+        out <- c(out,list(cause=cause))
     }
-    else{
-        tab <- data.frame(ltab)
-    }
-    if (model=="competing.risks")
-        out <- list(table=ltab,cause=cause)
-    else
-        out <- list(table=ltab)
-    out$model <- model
-    out$cotype <- cotype
     class(out) <- "summary.prodlim"
     out
     # }}}
