@@ -21,9 +21,9 @@ void prodlim_comprisk(double* y,
 		      double* event, 
 		      double* loss, 
 		      double* surv,
-		      double* cuminc,
+		      double* risk,
 		      double* cause_hazard,
-		      double* varcuminc,
+		      double* varrisk,
 		      double* I, /* current cumulative incidence */ 
 		      double*I_lag, /* time lagged cumulative incidence */ 
 		      double* v1,
@@ -73,12 +73,12 @@ void prodlim_comprisk(double* y,
       nrisk[s]=n;
       d = 0;
       /* }}} */
-      /* {{{ loop over causes: compute cuminc */
+      /* {{{ loop over causes: compute risk */
       for(j=0; j < (*NS); ++j) {
 	cause_hazard[s * (*NS) + j] = (event[s * (*NS) + j] / n);
 	I_lag[j] = I[j];
 	I[j] += S * cause_hazard[s * (*NS) + j];
-	cuminc[s * (*NS) + j] = I[j];
+	risk[s * (*NS) + j] = I[j];
 	d += event[s * (*NS) + j];
       }
       /* }}} */
@@ -95,7 +95,7 @@ void prodlim_comprisk(double* y,
 	v2[j] += (I[j] * I[j]) * (d / (n * (n - d)))
 	  + ((S_lag * S_lag) * (n - d1) * d1) / (n * n * n)
 	  + (2 * I[j] * S_lag * d1) / (n * n);
-	varcuminc[s * (*NS) + j] = (I[j] * I[j]) *  varH - 2 * I[j] * v1[j] + v2[j];
+	varrisk[s * (*NS) + j] = (I[j] * I[j]) *  varH - 2 * I[j] * v1[j] + v2[j];
 	/* varH is greenwood's formula */
 	/* variance estimate Korn & Dorey (1992), Stat in Med, Vol 11, page 815 */
 	/* I1 = (I[j] - I_lag[j]) / 2; */
@@ -129,9 +129,9 @@ void prodlimCompriskPlus(double* y,
 			 double* event, 
 			 double* loss, 
 			 double* surv,
-			 double* cuminc,
+			 double* risk,
 			 double* cause_hazard,
-			 double* varcuminc,
+			 double* varrisk,
 			 double* I, /* current cumulative incidence */ 
 			 double* I_lag, /* time lagged cumulative incidence */ 
 			 double* v1,
@@ -168,12 +168,16 @@ void prodlimCompriskPlus(double* y,
   } else{
     if (*delayed==1){
       atrisk=0;
+      /* do not initialize with those that have entry times=0 because by convention in case of ties 
+	 entry happens after events and after censoring  */
       /* sort the delayed entry times */
       qsort(entrytime+start,
 	    (stop-start),
 	    (size_t) sizeof(double),
 	    (int (*)(const void *, const void *))(doubleNewOrder));
       e=start; /* index for delayed entry */
+      /* initialize the number at risk */
+
     }else{
       atrisk=(double) stop-start; /* (sub-)sample size */
     }
@@ -217,18 +221,19 @@ void prodlimCompriskPlus(double* y,
 	/* delayed entry: find number of subjects that
 	   entered at time[s] */
 	entered=0;
-	while(e<stop && entrytime[e]< y[i-1]){ /*entry happens at t+ events at t*/
+	while(e<stop && entrytime[e]< y[i-1]){ /*entry happens at t+ and events at t*/
 	  entered++;
 	  if (e==start || entrytime[e]>entrytime[e-1]){
 	    /* unless there is a tie between the current
 	       and the next entry-time, add time to list of times, increase s
 	       and move the values of event, loss etc. to the next event time */
 	    nrisk[s]=atrisk+entered;
-	    if (entrytime[e]!=time[s-1]){ /* if entrytime[e]==y[i] then only increase
-					the number at risk but not move the
-					time counter or the values of event, etc.
-				     */
-	      /* Rprintf("e=%d\ts=%d\tentrytime[e]=%1.2f\ty[i-1]=%1.2f\ttime[s-1]=%1.2f\ti=%d\t\n",e,s,entrytime[e],y[i-1],time[s-1],i); */
+	    if (s==0 || entrytime[e]!=time[s-1]){
+	      /* if entrytime[e]==time[s-1] then only increase
+		 the number at risk (done two lines above)
+		 but dont change the time counter or the values
+		 of event, etc.
+	      */
 	      for(j=0; j < (*NS); ++j) { 
 		event[(s+1) * (*NS) + j]=event[s * (*NS) + j];
 		event[s * (*NS) + j]=0;
@@ -238,18 +243,17 @@ void prodlimCompriskPlus(double* y,
 	      if (entrytime[e]<y[start]){
 		surv[s]=1;
 		for(j=0; j < (*NS); ++j) {
-		  cuminc[s * (*NS) + j]=0;
-		  varcuminc[s * (*NS) + j]=0;
+		  risk[s * (*NS) + j]=0;
+		  varrisk[s * (*NS) + j]=0;
 		}
 	      } else{
 		surv[s]=S_lag;
 		for(j=0; j < (*NS); ++j) {
-		  cuminc[s * (*NS) + j]=cuminc[(s-1) * (*NS) + j];
-		  varcuminc[s * (*NS) + j]=varcuminc[(s-1) * (*NS) + j];
+		  risk[s * (*NS) + j]=risk[(s-1) * (*NS) + j];
+		  varrisk[s * (*NS) + j]=varrisk[(s-1) * (*NS) + j];
 		}
 	      }
 	      time[s]=entrytime[e];
-	      /* Rprintf("e=%d\ts=%d\tentrytime[e]=%1.2f\ttime[s]=%1.2f\t\n",e,s,entrytime[e],time[s]); */
 	      s++;
 	    } 
 	  }
@@ -258,16 +262,15 @@ void prodlimCompriskPlus(double* y,
 	atrisk += (double) entered;
       }
       time[s]=y[i-1];
-      /* Rprintf("\nEventtime:s=%d\ti=%d\ttime[s]=%1.2f\tcause=%1.2f\n",s,i,time[s],cause[i]);  */
       nrisk[s]=atrisk;
       d = 0;
       /* }}} */
-      /* {{{ loop over causes: compute cuminc */
+      /* {{{ loop over causes: compute risk */
       for(j=0; j < (*NS); ++j) {
 	cause_hazard[s * (*NS) + j] = (event[s * (*NS) + j] / atrisk);
 	I_lag[j] = I[j];
 	I[j] += S * cause_hazard[s * (*NS) + j];
-	cuminc[s * (*NS) + j] = I[j];
+	risk[s * (*NS) + j] = I[j];
 	d += event[s * (*NS) + j];
       }
       /* }}} */
@@ -284,7 +287,7 @@ void prodlimCompriskPlus(double* y,
 	v2[j] += (I[j] * I[j]) * (d / (atrisk * (atrisk - d)))
 	  + ((S_lag * S_lag) * (atrisk - d1) * d1) / (atrisk * atrisk * atrisk)
 	  + (2 * I[j] * S_lag * d1) / (atrisk * atrisk);
-	varcuminc[s * (*NS) + j] = (I[j] * I[j]) *  varH - 2 * I[j] * v1[j] + v2[j];
+	varrisk[s * (*NS) + j] = (I[j] * I[j]) *  varH - 2 * I[j] * v1[j] + v2[j];
 	/* varH is greenwood's formula */
 	/* variance estimate Korn & Dorey (1992), Stat in Med, Vol 11, page 815 */
 	/* I1 = (I[j] - I_lag[j]) / 2; */
